===============================
flir_ptu
===============================

.. image:: https://img.shields.io/travis/planetarypy/flir_ptu.svg
        :target: https://travis-ci.org/planetarypy/flir_ptu

.. image:: https://img.shields.io/pypi/v/flir_ptu.svg
        :target: https://pypi.python.org/pypi/flir_ptu


Python Boilerplate contains all the boilerplate you need to create a Python package.

* Free software: BSD license
* Documentation: https://flir_ptu.readthedocs.org.

Features
--------

* TODO
